@@ -25,13 +25,11 @@
 #include "version.h"
 
 #include <QApplication>
-#include <QDebug>
 #include <QDesktopWidget>
 #include <QFileDialog>
 #include <QInputDialog>
 #include <QKeyEvent>
 #include <QMessageBox>
-#include <QSettings>
 #include <QStyle>
 #include <QToolBar>
 
@@ -62,7 +60,7 @@ MainWindow::MainWindow(const QCommandLineParser &arg_parser, QWidget *parent)
     QString url, title;
     if (!arg_parser.positionalArguments().isEmpty()) {
         url = arg_parser.positionalArguments().at(0);
-        (arg_parser.positionalArguments().size() > 1) ? title = arg_parser.positionalArguments().at(1) : title = url;
+        title = (arg_parser.positionalArguments().size() > 1) ? arg_parser.positionalArguments().at(1) : url;
     } else {
        url = "https://duckduckgo.com";
        title = "DuckDuckGo";
@@ -73,7 +71,6 @@ MainWindow::MainWindow(const QCommandLineParser &arg_parser, QWidget *parent)
 
 MainWindow::~MainWindow()
 {
-    QSettings settings(qApp->applicationName());
     settings.setValue("geometry", saveGeometry());
 }
 
@@ -82,10 +79,19 @@ void MainWindow::addToolbar()
     this->addToolBar(toolBar);
     this->setCentralWidget(webview);
 
-    toolBar->addAction(webview->pageAction(QWebPage::Back));
-    toolBar->addAction(webview->pageAction(QWebPage::Forward));
-    toolBar->addAction(webview->pageAction(QWebPage::Reload));
-    toolBar->addAction(webview->pageAction(QWebPage::Stop));
+    QAction *back;
+    QAction *forward;
+    QAction *reload;
+    QAction *stop;
+
+    toolBar->addAction(back = webview->pageAction(QWebPage::Back));
+    back->setShortcut(QKeySequence::Back);
+    toolBar->addAction(forward = webview->pageAction(QWebPage::Forward));
+    forward->setShortcut(QKeySequence::Forward);
+    toolBar->addAction(reload = webview->pageAction(QWebPage::Reload));
+    reload->setShortcuts(QList<QKeySequence>({QKeySequence::Refresh, QKeySequence(tr("Ctrl+R"))}));
+    toolBar->addAction(stop = webview->pageAction(QWebPage::Stop));
+    reload->setShortcut(Qt::Key_Escape);
 
     searchBox->setPlaceholderText(tr("search"));
     searchBox->setClearButtonEnabled(true);
@@ -107,32 +113,32 @@ void MainWindow::addToolbar()
 
 void MainWindow::openBrowseDialog()
 {
-    QString file = QFileDialog::getOpenFileName(this, tr("Select file to open"), QDir::homePath(), tr("Hypertext Files (*.htm *.html);;All Files (*.*)"));
+    QString file = QFileDialog::getOpenFileName(this, tr("Select file to open"),
+                                                QDir::homePath(), tr("Hypertext Files (*.htm *.html);;All Files (*.*)"));
     if (QFileInfo::exists(file)) displaySite(file, file);
 }
 
 // pop up a window and display website
 void MainWindow::displaySite(QString url, QString title)
 {
-    int width = 800;
-    int height = 500;
-    this->resize(width, height);
-
-    QSettings settings(qApp->applicationName());
+    QSize size {800, 500};
+    this->resize(size);
     if (settings.contains("geometry")) {
         restoreGeometry(settings.value("geometry").toByteArray());
         if (this->isMaximized()) { // add option to resize if maximized
-            this->resize(width, height);
+            this->resize(size);
             centerWindow();
         }
     } else {
         centerWindow();
     }
 
+    disconnect(conn);
+    conn = connect(webview, &QWebView::loadFinished, [url](bool ok) { if (!ok) qDebug() << "Error loading:" << url; });
     webview->load(QUrl::fromUserInput(url));
     webview->show();
 
-    loading(); // display loading progressBar    
+    loading(); // display loading progressBar
     this->setWindowTitle(title);
 }
 
@@ -140,8 +146,8 @@ void MainWindow::displaySite(QString url, QString title)
 void MainWindow::centerWindow()
 {
     QRect screenGeometry = QApplication::desktop()->screenGeometry();
-    int x = (screenGeometry.width()-this->width()) / 2;
-    int y = (screenGeometry.height()-this->height()) / 2;
+    int x = (screenGeometry.width() - this->width()) / 2;
+    int y = (screenGeometry.height() - this->height()) / 2;
     this->move(x, y);
 }
 
@@ -180,37 +186,27 @@ void MainWindow::findInPage()
 // process keystrokes
 void MainWindow::keyPressEvent(QKeyEvent *event)
 {
-    qreal zoom = webview->zoomFactor();
-    if (event->matches(QKeySequence::Find) || event->key() == Qt::Key_F3) {
+    auto zoom = webview->zoomFactor();
+    if (event->matches(QKeySequence::Find) || event->key() == Qt::Key_F3)
         search();
-    } else if (event->key() == Qt::Key_Escape) {
-        done(false);
-    } else if (event->key() == Qt::Key_Plus) {
+    else if (event->key() == Qt::Key_Plus)
         webview->setZoomFactor(zoom + 0.1);
-    } else if (event->key() == Qt::Key_Minus) {
+    else if (event->key() == Qt::Key_Minus)
         webview->setZoomFactor(zoom - 0.1);
-    } else if (event->key() == Qt::Key_0) {
+    else if (event->key() == Qt::Key_0)
         webview->setZoomFactor(1);
-    } else if (event->matches(QKeySequence::Back)) {
-        webview->back();
-    } else if (event->matches(QKeySequence::Forward)) {
-        webview->forward();
-    } else if (event->matches(QKeySequence::Refresh) ||
-               (event->key() == Qt::Key_R && (QApplication::keyboardModifiers() & Qt::ControlModifier))) {
-        webview->reload();            
-    } else if (event->matches(QKeySequence::Open)) {
+    else if (event->matches(QKeySequence::Open))
         openDialog();
-    } else if (event->key() == Qt::Key_B && (QApplication::keyboardModifiers() & Qt::ControlModifier)) {
+    else if (event->key() == Qt::Key_B && (QApplication::keyboardModifiers() & Qt::ControlModifier))
         openBrowseDialog();
-    } else if (event->key() == Qt::Key_Question || event->matches(QKeySequence::HelpContents)) {
+    else if (event->key() == Qt::Key_Question || event->matches(QKeySequence::HelpContents))
         openQuickInfo();
-    }
 }
 
 // resize event
 void MainWindow::resizeEvent(QResizeEvent*)
 {
-    progressBar->move(this->geometry().width()/2 - progressBar->width()/2, this->geometry().height() - 40);
+    progressBar->move(this->geometry().width() / 2 - progressBar->width() / 2, this->geometry().height() - 40);
 }
 
 // for colour scheme changes
@@ -236,7 +232,7 @@ void MainWindow::loading()
 {
     progressBar->setFixedHeight(20);
     progressBar->setTextVisible(false);
-    progressBar->move(this->geometry().width()/2 - progressBar->width()/2, this->geometry().height() - 40);
+    progressBar->move(this->geometry().width() / 2 - progressBar->width() / 2, this->geometry().height() - 40);
     progressBar->setFocus();
     progressBar->show();
     timer->start(100);
@@ -251,7 +247,7 @@ void MainWindow::done(bool)
     webview->stop();
     webview->setFocus();
     searchBox->clear();
-    progressBar->hide();       
+    progressBar->hide();
 }
 
 // advance progressbar
